@@ -13,6 +13,10 @@ Wed May  8 1991
 
 /* shot.c - handle movement, etc. of the shots. */
 
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
+
 #include "vaders.h"
 
 extern int paused;
@@ -90,7 +94,7 @@ XtIntervalId id;
     if (numshots > 0)
       shottimerid = XtAddTimeOut(shotwait, MoveShots, (Opaque) MoveShots);
     else
-      shottimerid = NULL;
+      shottimerid = 0;
     for (i=0 ; i<numshots ; i++) {
       shot = shots + i;
       newy = shot->y - SHOTSIZE/2;
@@ -143,7 +147,7 @@ XtIntervalId id;
     if (numvshots > 0)
       vshottimerid = XtAddTimeOut(vshotwait, MoveVshots, (Opaque) MoveVshots);
     else
-      vshottimerid = NULL;
+      vshottimerid = 0;
     for (i=0 ; i<numvshots ; i++) {
       vshot = vshots + i;
       newy = vshot->y + 2*scale;
@@ -178,7 +182,7 @@ int x, y;
     shot->x = x;
     shot->y = y-SHOTSIZE;
     PaintShot(shot, shotgc);
-    if (shottimerid == NULL)
+    if (shottimerid == 0)
         shottimerid = XtAddTimeOut(shotwait, MoveShots, (Opaque) MoveShots);
 }
 
@@ -192,7 +196,7 @@ int x, y;
     shot->x = x;
     shot->y = y;
     PaintVshot(shot, vshotgc);
-    if (vshottimerid == NULL)
+    if (vshottimerid == 0)
       vshottimerid = XtAddTimeOut(shotwait, MoveVshots, (Opaque) MoveVshots);
 }
 
@@ -230,14 +234,14 @@ int ReadVshotImages()
   return BitmapSuccess;
 }
 
-InitShot()
+void InitShot()
 {
-    shottimerid = NULL;
+    shottimerid = 0;
     numshots = 0;
-    vshottimerid = NULL;
+    vshottimerid = 0;
     numvshots = 0;
     if( ReadVshotImages() != BitmapSuccess) {
-      fprintf(stderr, "Error reading vshot images.\n");
+      fprintf(stderr, _("Error reading vshot images.\n"));
       exit(20);
     }
 }
