@@ -13,6 +13,10 @@ Wed May  8 1991
 
 /* spacers.c - handle movement, etc. of the little space ships. */
 
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
+
 #include "vaders.h"
 
 Boolean spacer_shown;
@@ -158,9 +162,9 @@ int ReadSpacerImages()
 void InitSpacers()
 {
   if(ReadSpacerImages()!= BitmapSuccess) {
-    fprintf(stderr, "Error reading Spacer image\n");
+    fprintf(stderr, _("Error reading Spacer image\n"));
     exit(10);
   }
 
-  spacertimerid = NULL;
+  spacertimerid = 0;
 }
